@@ -10,9 +10,6 @@ __email__ = ', '.join([
 
 from . import plotting  as pl
 from . import utilities as ut
-from . import machine_learning as ml
-from . import simulation as sm
 from . import single_cell as sc
-from . import math as ma
 from . import testing_and_development as dev
 from . import data
