@@ -9,4 +9,4 @@ from .color_palettes import shareseq_colors as share_seq
 
 from .share_seq_df_generation import shareseq_palette_df
 
-from ._histogram import _plot_histogram as histogram
\ No newline at end of file
+# from ._histogram import _plot_histogram as histogram
